package com.ym.mec.biz.dal.wrapper;

import com.alibaba.fastjson.JSON;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.ym.mec.biz.dal.entity.SysMusicScoreCategories;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.Date;
import java.util.List;
import java.util.Optional;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.NotNull;

public class MemberRankSettingWrapper {


    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @ApiModel(" MemberRankSettingQuery-会员等级设置")
    public static class MemberRankSettingQuery implements QueryInfo {

        @ApiModelProperty("名称")
        private String name;

        @ApiModelProperty("更新开始时间")
        private Date updateStartTime;

        @ApiModelProperty("更新结束时间")
        private Date updateEndTime;

        @ApiModelProperty("更新人名称")
        private String updateName;

        @ApiModelProperty("会员编号")
        private List<Integer> memberIds;

        @ApiModelProperty("查询有子节点的数据")
        private Boolean hasChildren;

        @ApiModelProperty("移除ID")
        private List<Integer> removeIds;

        @ApiModelProperty("学生ID")
        private Integer studentId;

        @ApiModelProperty("是否删除")
        private Boolean delFlag = false;

        public String jsonString() {
            return JSON.toJSONString(this);
        }

        public static MemberRankSettingQuery from(String json) {
            return JSON.parseObject(json, MemberRankSettingQuery.class);
        }
    }


    @Data
    @ApiModel(" MemberRankSettingAdd-会员等级设置")
    public static class MemberRankSettingAdd {

        private Integer id;

        @ApiModelProperty("父级编号")
        private Integer parentId;

        @ApiModelProperty("名称")
        @NotNull(message = "名称不能为空")
        private String name;

        @ApiModelProperty("介绍")
        @NotNull(message = "介绍不能为空")
        private String intro;

        @ApiModelProperty("更新时间")
        private Date updateTime;

        @ApiModelProperty("更新人")
        private Integer operator;

        @ApiModelProperty("学练宝曲目分类内容")
        private List<Integer> memberCategoryIdList;


        @ApiModelProperty("学练宝云课堂内容")
        private List<String> memberCourseTypeList;

        @ApiModelProperty("学练宝功能")
        private List<Integer> memberPrivilegesItemIdList;
    }

    @Data
    @ApiModel(" MemberRankSetting-会员等级设置")
    public static class MemberRankSetting {

        private Integer id;

        @ApiModelProperty("父级编号")
        private Integer parentId;

        @ApiModelProperty("父级名称")
        private String parentName;

        @ApiModelProperty("名称")
        private String name;

        @ApiModelProperty("介绍")
        private String intro;

        @ApiModelProperty("曲目数量")
        private Integer musicCount = 0;

        @ApiModelProperty("更新时间")
        private Date updateTime;

        @ApiModelProperty("更新人")
        private Integer operator;

        @ApiModelProperty("是否已被购买")
        private Boolean buyFlag;

        @ApiModelProperty("子节点")
        private List<MemberRankSetting> children;


        @ApiModelProperty("更新人名称")
        private String operatorName;

        @ApiModelProperty("学练宝曲目分类内容 详情接口返回")
        private List<Integer> memberCategoryIdList;


        @ApiModelProperty("学练宝云课堂内容 详情接口返回")
        private List<String> memberCourseTypeList;

        @ApiModelProperty("学练宝功能 详情接口返回")
        private List<Integer> memberPrivilegesItemIdList;
        public String jsonString() {
            return JSON.toJSONString(this);
        }

        public static MemberRankSetting from(String json) {
            return JSON.parseObject(json, MemberRankSetting.class);
        }
    }



    @Data
    @ApiModel(" Category-会员等级设置")
    public static class Category {

        @ApiModelProperty("曲目分类")
        private List<SysMusicScoreCategories> musicScoreCategories;

        @ApiModelProperty("学练宝云课堂内容")
        private List<SysMusicScoreCategories> lessonCategories;
    }
}
