package com.ym.mec.biz.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ym.mec.biz.dal.entity.MemberRankCategoryMapper;
import com.ym.mec.biz.dal.mapper.MemberRankCategoryMapperMapper;
import com.ym.mec.biz.service.MemberRankCategoryMapperService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

/**
 * 会员分类权限表
 * 2024-10-22 14:51:51
 */
@Slf4j
@Service
public class MemberRankCategoryMapperServiceImpl extends ServiceImpl<MemberRankCategoryMapperMapper, MemberRankCategoryMapper> implements MemberRankCategoryMapperService {

    @Override
    public void batchInsert(Integer memberRankSettingId, List<Integer> memberCategoryIdList) {
        if (CollectionUtils.isNotEmpty(memberCategoryIdList)) {
            List<MemberRankCategoryMapper> memberRankCategoryMappers = new ArrayList<>();
            for (Integer i : new HashSet<>(memberCategoryIdList)) {
                MemberRankCategoryMapper memberRankCategoryMapper = new MemberRankCategoryMapper();
                memberRankCategoryMapper.setRankId(memberRankSettingId);
                memberRankCategoryMapper.setCategoryId(i);
                memberRankCategoryMappers.add(memberRankCategoryMapper);
            }
            this.saveBatch(memberRankCategoryMappers);
        }
    }

    @Override
    public List<MemberRankCategoryMapper> getByMemberRankId(List<Integer> memberRankSettingId) {
        if (CollectionUtils.isEmpty(memberRankSettingId)) {
            return new ArrayList<>();
        }
        return lambdaQuery()
            .in(MemberRankCategoryMapper::getRankId, memberRankSettingId)
            .list();

    }

    @Override
    public void deleteByRankSettingId(Integer memberRankSettingId) {
        lambdaUpdate()
            .eq(MemberRankCategoryMapper::getRankId, memberRankSettingId)
            .remove();
    }
}